close all
clear all

% references:

% A. Gani et al. Journal of Process Control, 17 (2007), pp. 439-451

% temperature control of industrial gas phase polyethylene reactors, S. A. Dadebo, 
% P. J. McLellan and K. B. McAuley, J Proc. Cont. Vol. 7 No. 2, pp. 83 -
% 95, 1997.

% effects of perating conditions on stability of gas-phase polyethylene reactors, K. B. McAuley,
% D. A. Macdonald, and P. J. Mclellan, AIChE Journal, Vol. 41, pp. 868-879

% specify simulation time:
tspan       = [0, 3600*10];

% specify initial condition for simulation:
In_con_ss   = 483.5818; % mol/m3            Molar concentration of inert in the gas phase
M1_con_ss   = 218.6872; % mol/m3            Molar concentration of ethylene in the gas phase
Y1_ss       = 5.0385;  % mol;               Moles of active site type 1
Y2_ss       = 5.0385;  % mol;               Moles of active site type 2
% T_ss        = 356.21; % k  
T_ss        = 360.06; % k                   Reactor temperature
Tw1_ss      = 290.3755; % k                 Cooling water temperature from exchanger
Tg1_ss      = 294.3801; % k                 Recycle gas temperature

y0        = [In_con_ss M1_con_ss Y1_ss Y2_ss T_ss Tw1_ss Tg1_ss]';

% specify parameter value:
ac          = 0.548; % mol/kg
kp0         = 85e-3;      % m3/(mol*s)
Ea          = 9e3*4.1868; % J/mol
kd1         = 1e-4;  % s^-1
kd2         = 1e-4;  % s^-1

theta       = [ac kp0*10 Ea*1e-5 kd1*1e3 kd2*1e3];

% for control & sampling:
tsp         = [1 : 10] * 3600;   % sampling time
Fc_ss       = 1.5/3600;  %kg/s
Tfeed_ss    = 293; %k
Fc          = Fc_ss *    ones(1,5);  % step control signal value
Tfeed       = Tfeed_ss * ones(1,5);  % step control signal value
phi         = [tsp Fc Tfeed];
phifix      = [2:2:10,2:2:10] * 3600; % control signal chance time

% give numerical integration options for ode15s:
odeoptions = odeset('RelTol',1e-4,'AbsTol',1e-4);
% do integration:
[t,y]      = ode15s(@(t,x) polyeth(t,x,flag,theta,[phi,phifix]), tspan, y0,...
    odeoptions);

% added by jdh
figure(1)
hold off
for i = 1:7
    subplot(7,1,i);
    hold on;
    plot(t,y(:,i));
    switch i
    case(1)
        ylabel('c_{inert}')
    case(2)
        ylabel('c_{c2=}')
    case(3)
        ylabel('c_{as1}')
    case(4)
        ylabel('c_{as2}')
    case(5)
        ylabel('Trx')
    case(6)
        ylabel('Tcool')
    case(7)
        ylabel('Tcg')
    end
end
