function y = polyeth(t,x,flag,theta,phi)

% (C)YANG ZHANG, UT-Austin, Oct. 2007

% reference:
% temperature control of industrial gas phase polyethylene reactors, S. A. Dadebo, 
% P. J. McLellan and K. B. McAuley, J Proc. Cont. Vol. 7 No. 2, pp. 83 - 95, 1997.


% define control:


% tsp        = phi(1:10);
Fc_temp    = phi(11:15);
Tfeed_temp = phi(16:20);

tsw1       = phi(21:25);
tsw2       = phi(26:30);


order1     = length(find((t - tsw1) > 0)) + 1; 
order2     = length(find((t - tsw2) > 0)) + 1;

if order1 > length(tsw1)
    order1 = length(tsw1);
end

if order2 > length(tsw2)
    order2 = length(tsw2);
end

Fc         = Fc_temp(order1);
Tfeed      = Tfeed_temp(order2);

% define constants:
Vg          = 500;    % m3
Vp          = 0.5;
Pv          = 17;     % atm
Bw          = 7e4;    % kg
% kp0         = 85e-3;      % m3/(mol*s)
% Ea          = 9e4*4.1868; % J/mol
Cpm1        = 11*4.1868;  % J/(mol*k)
Cv          = 7.5;      % atm^-0.5
Cpw         = 4.1868e3; % J/(kg*k)
CpIn        = 6.9*4.1868; % J/(kg*k)
Cppol       = 0.85e3 * 4.1868;  % J/(kg*k)
% kd1         = 1e-4;  % s^-1
% kd2         = 1e-4;  % s^-1
Mw1         = 28.05e-3;   % kg/mol
Mw          = 3.314e4;    % kg
Mg          = 6060.5;     % mol
MrCpr       = 1.4*4.1868e7; % J/k
Hreac       = -894*4.1868e3; % J/kg
UA          = 1.14*4.1868e6; % J/(K*s)
FIn         = 5;   %mol/s
FM1         = 190; %mol/s
Fg          = 8500; %mol/s
Fw          = 3.11e5*18e-3; % kg/s
% Fc_ss       = 5.8/3600;  %kg/s
Tf          = 360;  %k
% Tfeed_ss    = 293; %k
Twi         = 289.56;  % k
RR          = 8.20575e-5; % m3*atm/(mol*k)
R           = 8.314; % J/(mol*k)
% ac          = 0.548; % mol/kg
% Inert_con_ss   = 439.68; % mol/m3
% M1_con_ss   = 326.72;  % mol/m3
% Y1_ss       = 3.835; %mol
% Y2_ss       = 3.835; %mol
% T_ss        = 356.21; % K
% Tw1_ss      = 290.37; % K
% Tg1_ss      = 294.36; % K



% define x:
In_con      = x(1);
M1_con      = x(2);
Y1          = x(3);
Y2          = x(4);
T           = x(5);
Tw1         = x(6);
Tg1         = x(7);


% define parameter theta:
ac          = theta(1);
kp0         = theta(2) *1e-1;
Ea          = theta(3) *1e5;
kd1         = theta(4) *1e-3;
kd2         = theta(5) *1e-3;


% Algebric equations:
bt          = Vp * Cv * sqrt((M1_con+In_con) * RR * T - Pv);
RM1         = M1_con * kp0 * exp(-Ea/R*(1/T-1/Tf)) * (Y1+Y2);
Cpg         = M1_con/(M1_con + In_con) * Cpm1 + In_con/(M1_con + In_con) * CpIn;
Hf          = FM1 * Cpm1 * ( Tfeed - Tf) + FIn * CpIn * (Tfeed - Tf);
Hg1         = Fg * (Tg1 - Tf) * Cpg;
Hg0         = (Fg + bt) * (T - Tf) * Cpg;
Hr          = Hreac * Mw1 * RM1;
Hpol        = Cppol * (T - Tf) * RM1 * Mw1;


% Differential equations:

dIn_con     = (FIn - In_con/(M1_con + In_con) * bt)/Vg;
dM1_con     = (FM1 - M1_con/(M1_con + In_con) * bt - RM1)/Vg;
dY1         = Fc * ac - kd1 * Y1 - RM1 * Mw1 * Y1/ Bw;
dY2         = Fc * ac - kd2 * Y2 - RM1 * Mw1 * Y2/ Bw;
dT          = (Hf + Hg1 - Hg0 - Hr - Hpol)/(MrCpr + Bw * Cppol);
dTw1        = Fw/Mw * (Twi - Tw1) - UA/(Mw * Cpw) * (Tw1 - Tg1);
dTg1        = Fg/Mg * (T - Tg1)   + UA/(Mg * Cpg) * (Tw1 - Tg1);


 y = [dIn_con dM1_con dY1 dY2 dT dTw1 dTg1]';
 
